@@ -859,7 +859,8 @@ sub get_movix_version {
 
     $movixversion = "eMoviX-" . `echo -n \$(movix-version 2>/dev/null)`;
     # Desactivate the menu language selection for installed eMoviX
-    $xml_root->get_widget ("optionmenu_menu_lang")->set_sensitive(FALSE);
+    $xml_root->get_widget ("optionmenu_menu_lang")->set_sensitive(FALSE)
+      unless (defined $options{'nogui'});
 
     $statusbar->set_status("Detected $movixversion.")
       unless (defined $options{'nogui'});
